<?
	#---------------------------------------------------------------------#
	# This source code is (c)2000 White Pajamas, Inc                      #
	# see http://www.stonekeep.com/license.html for licensing information #
	#---------------------------------------------------------------------#

	#--------------------------------------------------------------------
	# $Id: modver.php3,v 1.2 2000/12/14 19:13:51 shevett Exp $
	#--------------------------------------------------------------------
	
	include "./verutils.php3";

?>

<?
	$col[bghigh]='#dddddd';
	$col[bglow]='#808080';
	$col[back]='#000000';
	
	Function CloseRow()
	{
		echo "</tr>";
	}

	Function OpenRow()
	{
		Global $col;
		echo "<tr bgcolor=$col[bghigh] valign=top>\n";
	}

	Function CellInfo($tinfo) 
	{
		Global $col;
		echo "<td bgcolor=$col[bglow]>\n";
		echo "$tinfo\n";
		echo "</td>\n";
	}

	Function CellQuery($label,$iname,$default)
	{
		Global $col,$currow;
		echo "<td bgcolor=$col[bglow]>\n";
		echo "<i>$label</i><br>\n";
		if ($currow[$iname]) {
			$dispval = $currow[$iname];
		} else {
			$dispval = $default;
		}
		echo "<input type=text name=a_$iname value=\"$dispval\">\n";
		echo "</td>\n";
	}

?>

	<form method="post" action="nbrowse.php3">
	<input type=hidden name="f_process" value="postver">
	<input type=hidden name="a_v_id" value="<? echo $sid?>">
	<tr bgcolor=#BBBBCB>
		<td width=100% bgcolor=<? echo $col[back] ?>>
		<table bgcolor=<? echo $col[bghigh] ?> cellspacing=2 align=center>
		<tr>
			<td align=center colspan=2>
				Modify Version information for Slip # <? echo $sid ?>
			</td>
		</tr>
	<?
		# fetch out the old slip version information
		$svq = db_query("select * from slipver where v_id=$sid");
		$svinfo = db_fetch_array($svq) ;

		OpenRow();
			echo "<td bgcolor=$col[bglow]>";
			ChooseProduct("a_v_prod","$svinfo[v_prod]");
			echo "</td>";
			CellInfo("What product was this reported in?");
		CloseRow();
		OpenRow();
			echo "<td bgcolor=$col[bglow]>";
			ChooseModule("a_v_mod","$svinfo[v_mod]");
			echo "</td>";
			CellInfo("What Module was this reported in?");
		CloseRow();
		OpenRow();
			echo "<td bgcolor=$col[bglow]>";
			ChoosePlatform("a_v_plat","$svinfo[v_plat]");
			echo "</td>";
			CellInfo("What platform was this reported on?");
		CloseRow();
		OpenRow();
			echo "<td bgcolor=$col[bglow]>";
			ChooseVersion("a_v_foundin","$svinfo[v_foundin]","Found in");
			echo "</td>";
			CellInfo("What version was this reported in?");
		CloseRow();
		OpenRow();
			echo "<td bgcolor=$col[bglow]>";
			ChooseVersion("a_v_target","$svinfo[v_target]","Target");
			echo "</td>";
			CellInfo("What version is the target for a fix for this slip?");
		CloseRow();
		OpenRow();
			echo "<td bgcolor=$col[bglow]>";
			ChooseVersion("a_v_verify","$svinfo[v_verify]","Verified");
			echo "</td>";
			CellInfo("What version was this verified fixed?");
		CloseRow();
		OpenRow();
			echo "<td bgcolor=$col[bglow]>";
			ChooseRescode("a_v_resolve","$svinfo[v_resolve]");
			echo "</td>";
			CellInfo("What was the resolution on this?");
		CloseRow();
?>
	
	<tr bgcolor=#000000>
		<td colspan=4>
	<?  
		PostBar("Post Modifications"); 
	?>
		</td>
	</tr>
	</table>
	</td>
	</tr>
